@@ -5,11 +5,11 @@ Paired density and scatterplot matrix
 _thumb: .5, .5
 """
 import seaborn as sns
-sns.set(style="white")
+sns.set_theme(style="white")
 
-df = sns.load_dataset("iris")
+df = sns.load_dataset("penguins")
 
 g = sns.PairGrid(df, diag_sharey=False)
-g.map_upper(sns.scatterplot)
-g.map_lower(sns.kdeplot, colors="C0")
+g.map_upper(sns.scatterplot, s=15)
+g.map_lower(sns.kdeplot)
 g.map_diag(sns.kdeplot, lw=2)
